@@ -123,7 +123,8 @@ class ParserRemoto:
                 maquina_virtual.get('QtdeRam'),
                 vms_rede,
                 maquina_virtual.get('ID'),
-                maquina_virtual.get('VirtAninhada'),
+                maquina_virtual.get('VirtualizacaoAninhada'),
+                maquina_virtual.get('MemoriaDinamica'),
                 VMStatusEnum(maquina_virtual.get('Status')),
                 maquina_virtual.get('NoRegiao'),
             )
